@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, TYPE_CHECKING, overload
+from typing import Any, Dict, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
 from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
@@ -35,35 +35,35 @@ __all__ = ("AugmentedAIRuntimeClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ConflictException: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceQuotaExceededException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceQuotaExceededException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class AugmentedAIRuntimeClient:
     """
-    [AugmentedAIRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
+    [AugmentedAIRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
         """
 
     def delete_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Client.delete_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
+        [Client.delete_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
         """
 
     def describe_human_loop(self, HumanLoopName: str) -> DescribeHumanLoopResponseTypeDef:
         """
-        [Client.describe_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
+        [Client.describe_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
         """
 
     def generate_presigned_url(
@@ -74,7 +74,7 @@ class AugmentedAIRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
         """
 
     def list_human_loops(
@@ -87,7 +87,7 @@ class AugmentedAIRuntimeClient:
         MaxResults: int = None,
     ) -> ListHumanLoopsResponseTypeDef:
         """
-        [Client.list_human_loops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
+        [Client.list_human_loops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
         """
 
     def start_human_loop(
@@ -98,16 +98,16 @@ class AugmentedAIRuntimeClient:
         DataAttributes: HumanLoopDataAttributesTypeDef = None,
     ) -> StartHumanLoopResponseTypeDef:
         """
-        [Client.start_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
+        [Client.start_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
         """
 
     def stop_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
+        [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_human_loops"]) -> ListHumanLoopsPaginator:
         """
-        [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+        [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
         """
